//	see http://processors.wiki.ti.com/index.php/I2C_Tips

#ifndef __I2C_OFFSETS_H_INCLUDED
#define __I2C_OFFSETS_H_INCLUDED

// offsets originally from BSP ti-am335x-beaglebone-SDP6.6-SAM/BBB_BSP/src/hardware/i2c/omap35xx/arm/j5/offsets.h

#define AM335x_I2C_REVNB_LO     0x000  // Module Revision Register (low bytes)
#define AM335x_I2C_REVNB_HI     0x004  //    "              "      (hi bytes)
#define AM335x_I2C_SYSC         0x010  // System Configuration Register
	#define	AM335x_I2C_AUTOIDLE		(1 << 0)	// I2C Module AutoIdle Bit
	#define	AM335x_I2C_SRST			(1 << 1)	// I2C Module SoftReset Bit
	#define	AM335x_I2C_ENAWAKEUP	(1 << 2)	// I2C Module Enable Wakeup Bit
	#define	AM335x_I2C_IDLEMODE_NONE	(1 << 3)	// I2C Module SoftReset Bit
	#define	AM335x_I2C_IDLEMODE_SMART	(2 << 3)	// I2C Module SoftReset Bit
	#define	AM335x_I2C_IDLEMODE_SMARTWAKE	(3 << 3)	// I2C Module SoftReset Bit
	#define	AM335x_I2C_CLKACT_OCP			(1 << 8)	// I2C Module SoftReset Bit
	#define	AM335x_I2C_CLKACT_SYS			(2 << 8)	// I2C Module SoftReset Bit
	#define	AM335x_I2C_CLKACT_BOTH			(3 << 8)	// I2C Module SoftReset Bit
#define AM335x_I2C_IRQSTAT_RAW  0x024  // I2C Status Raw Register
	#define	AM335x_I2C_AL		(1 << 0)	// I2C Arbitration Lost
	#define	AM335x_I2C_NACK		(1 << 1)	// I2C Nack
	#define	AM335x_I2C_ARDY		(1 << 2)	// I2C Receive/Transmit done status ready
	#define	AM335x_I2C_RRDY		(1 << 3)	// I2C Receive data ready
	#define	AM335x_I2C_XRDY		(1 << 4)	// I2C Transmit data ready
	#define	AM335x_I2C_GC		(1 << 5)	// I2C General Call
	#define	AM335x_I2C_STC		(1 << 6)	// I2C Start condition
	#define	AM335x_I2C_AERR		(1 << 7)	// I2C Access Error
	#define	AM335x_I2C_BF		(1 << 8)	// I2C Bus Free
	#define	AM335x_I2C_AAS		(1 << 9)	// I2C Addressed As Slave
	#define	AM335x_I2C_XUDF		(1 << 10)	// I2C Transmit Underflow
	#define	AM335x_I2C_ROVR		(1 << 11)	// I2C Receive Overrun
	#define	AM335x_I2C_BB		(1 << 12)	// I2C Bus Busy
	#define	AM335x_I2C_RDR		(1 << 13)	// I2C Receive Draining
	#define	AM335x_I2C_XDR		(1 << 14)	// I2C Transmit Draining
#define AM335x_I2C_STAT         0x028  // I2C Status Register
#define AM335x_I2C_IE_SET       0x02C  // I2C Interrupt Enable Set Register
#define AM335x_I2C_IE_CLR       0x030  //       "          "   Clr    "
#define AM335x_I2C_WE           0x034  // I2C Wakeup Enable  Register
	#define AM335x_I2C_WE_ALL         0x6F6F	// Wakeup enable all to avoid hanging i2c bus
#define AM335x_I2C_DMARXEN_SET  0x038  // Receive DMA Enable Set Register
#define AM335x_I2C_DMATXEN_SET  0x03C  // Transmit DMA Enable Set Register
#define AM335x_I2C_DMARXEN_CLR  0x040  // Receive DMA Enable Clear Register
#define AM335x_I2C_DMATXEN_CLR  0x044  // Transmit DMA Enable Clear Register
#define AM335x_I2C_DMARXWAKE_EN 0x048  // Receive DMA Wakeup Register
#define AM335x_I2C_DMATXWAKE_EN 0x04C  // Transmit DMA Wakeup Register

#define AM335x_I2C_SYSS         0x090  // System Status Register
	#define	AM335x_I2C_SYSS_RDONE			(1 << 0)	// I2C Module Reset Done Bit
#define AM335x_I2C_BUF          0x094  // Buffer Configuration Register
#define AM335x_I2C_CNT          0x098  // Data Counter Register
#define AM335x_I2C_DATA         0x09C  // Data Access Register
#define AM335x_I2C_CON          0x0A4  // I2C Configuration Register // value@reset=0
	#define	AM335x_I2C_EN			(1 << 15)	// I2C Module Enable
	#define	AM335x_STB				(1 << 11)	// Start Byte Mode (I2C Master Mode Only)
	#define	AM335x_MST				(1 << 10)	// Master/Slave Mode 1=Master 0=Slave
	#define	AM335x_TRX				(1 << 9)	// Xmit/Receive Mode (I2C Master Mode Only)
	#define	AM335x_XSA				(1 << 8)	// Expand Slave Address
	#define	AM335x_XOA0				(1 << 7)	// Expand Own Address 0
	#define	AM335x_XOA1				(1 << 6)	// Expand Own Address 1
	#define	AM335x_XOA2				(1 << 5)	// Expand Own Address 2
	#define	AM335x_XOA3				(1 << 4)	// Expand Own Address 3
	#define	AM335x_STP				(1 << 1)	// Stop Condition (I2C Master Mode Only)
	#define	AM335x_STT				(1 << 0)	// Start Condition (I2C Master Mode Only)
#define AM335x_I2C_OA           0x0A8  // I2C Own Address Register // value@reset=0
#define AM335x_I2C_SA           0x0AC  // I2C Slave Address Register
#define AM335x_I2C_PSC          0x0B0  // I2C Clock Prescaler Register // value@reset=0
#define AM335x_I2C_SCLL         0x0B4  // I2C SCL Low Time Register
#define AM335x_I2C_SCLH         0x0B8  // I2C SCL High Time Register
#define AM335x_I2C_SYSTEST      0x0BC  // System Test Register
#define AM335x_I2C_BUFSTAT      0x0C0  // I2C Buffer Status Register
                                      
#define AM335x_I2C_OA1          0x0C4  // I2C Own Address 1 Register
#define AM335x_I2C_OA2          0x0C8  // I2C Own Address 2 Register
#define AM335x_I2C_OA3          0x0CC  // I2C Own Address 3 Register
#define AM335x_I2C_ACTOA        0x0D0  // I2C Active Own Address Register
#define AM335x_I2C_SBLOCK       0x0D4  // I2C Clock Blocking Enable Register
	#define	AM335x_OAE0				(1 << 0)	// Enable I2C blocking for own address 0

#define AM335x_I2C_STAT_MASK (	  \
				AM335x_I2C_RDR  | \
				AM335x_I2C_XDR  | \
				AM335x_I2C_ROVR | \
				AM335x_I2C_XUDF | \
				AM335x_I2C_AAS  | \
				AM335x_I2C_GC   | \
				AM335x_I2C_XRDY | \
				AM335x_I2C_RRDY | \
				AM335x_I2C_ARDY | \
				AM335x_I2C_NACK | \
				AM335x_I2C_AL)
#define AM335x_I2C_INT_MASK	( AM335x_I2C_XRDY | AM335x_I2C_RRDY | AM335x_I2C_ARDY )
#define AM335x_I2C_INT_RCV	( AM335x_I2C_RRDY | AM335x_I2C_ARDY )
#define AM335x_I2C_INT_XMT	( AM335x_I2C_XRDY | AM335x_I2C_ARDY )
#define AM335x_I2C_MST_RCV	( AM335x_I2C_RRDY | AM335x_I2C_BB )
#define AM335x_I2C_MST_XMT	( AM335x_I2C_XRDY | AM335x_I2C_XUDF | AM335x_I2C_BB )
//#define AM335x_I2C_MST_XMT	( AM335x_I2C_XRDY | AM335x_I2C_BB )
//#define AM335x_I2C_SLV_RCV	( AM335x_I2C_RRDY | AM335x_I2C_ROVR | AM335x_I2C_AAS | AM335x_I2C_BB )
//#define AM335x_I2C_SLV_RCV	( AM335x_I2C_RRDY | AM335x_I2C_ROVR | AM335x_I2C_AAS )
//#define AM335x_I2C_SLV_RCV	( AM335x_I2C_RRDY | AM335x_I2C_AAS | AM335x_I2C_BB )
#define AM335x_I2C_SLV_RCV	( AM335x_I2C_RRDY | AM335x_I2C_AAS )
#define AM335x_I2C_SLV_XMT	( AM335x_I2C_XRDY | AM335x_I2C_XUDF | AM335x_I2C_AAS | AM335x_I2C_BB )
//#define AM335x_I2C_SLV_XMT	( AM335x_I2C_XRDY | AM335x_I2C_AAS )
#define	AM335x_I2C_RESET (		  \
				AM335x_I2C_RDR  | \
				AM335x_I2C_XDR  | \
				AM335x_I2C_ROVR | \
				AM335x_I2C_XUDF | \
				AM335x_I2C_AAS  | \
				AM335x_I2C_AERR | \
				AM335x_I2C_STC  | \
				AM335x_I2C_GC   | \
				AM335x_I2C_XRDY | \
				AM335x_I2C_RRDY | \
				AM335x_I2C_ARDY | \
				AM335x_I2C_NACK | \
				AM335x_I2C_AL)
#define	AM335x_I2C_ERROR (		  \
				AM335x_I2C_RDR  | \
				AM335x_I2C_XDR  | \
				AM335x_I2C_AERR | \
				AM335x_I2C_STC  | \
				AM335x_I2C_GC   | \
				AM335x_I2C_NACK | \
				AM335x_I2C_AL)
#define	AM335x_I2C_RESET_ERROR (		  \
				AM335x_I2C_RDR  | \
				AM335x_I2C_XDR  | \
				AM335x_I2C_AERR | \
				AM335x_I2C_STC  | \
				AM335x_I2C_GC   )
#endif
